"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DbRevertMigrationCommand = void 0;
const core_1 = require("@oclif/core");
const typeorm_1 = require("@n8n/typeorm");
const typedi_1 = require("typedi");
const Logger_1 = require("../../Logger");
const Db_1 = require("../../Db");
const config_1 = require("../../databases/config");
const migrationHelpers_1 = require("../../databases/utils/migrationHelpers");
const config_2 = __importDefault(require("../../config"));
class DbRevertMigrationCommand extends core_1.Command {
    constructor() {
        super(...arguments);
        this.logger = typedi_1.Container.get(Logger_1.Logger);
    }
    async init() {
        await this.parse(DbRevertMigrationCommand);
    }
    async run() {
        const dbType = config_2.default.getEnv('database.type');
        const connectionOptions = {
            ...(0, config_1.getConnectionOptions)(),
            subscribers: [],
            synchronize: false,
            migrationsRun: false,
            dropSchema: false,
            logging: ['query', 'error', 'schema'],
        };
        connectionOptions.migrations.forEach(migrationHelpers_1.wrapMigration);
        this.connection = new typeorm_1.DataSource(connectionOptions);
        await this.connection.initialize();
        if (dbType === 'postgresdb')
            await (0, Db_1.setSchema)(this.connection);
        await this.connection.undoLastMigration();
        await this.connection.destroy();
    }
    async catch(error) {
        this.logger.error('Error reverting last migration. See log messages for details.');
        this.logger.error(error.message);
    }
    async finally(error) {
        var _a;
        if ((_a = this.connection) === null || _a === void 0 ? void 0 : _a.isInitialized)
            await this.connection.destroy();
        this.exit(error ? 1 : 0);
    }
}
exports.DbRevertMigrationCommand = DbRevertMigrationCommand;
DbRevertMigrationCommand.description = 'Revert last database migration';
DbRevertMigrationCommand.examples = ['$ n8n db:revert'];
DbRevertMigrationCommand.flags = {
    help: core_1.Flags.help({ char: 'h' }),
};
//# sourceMappingURL=revert.js.map